pub enum ConnectError {
MaximumConnectionsReached {
limit: u16,
},
AlreadyConnecting {
address: SocketAddr,
},
AlreadyConnected {
address: SocketAddr,
},
SelfConnect {
address: SocketAddr,
},
BannedIp {
ip: IpAddr,
},
IoError(Error),
ApplicationError(Box<dyn ApplicationError>),
Other(Box<dyn Error + Send + Sync>),
}Expand description
Error types for the Tcp::connect function.
Variants
MaximumConnectionsReached
AlreadyConnecting
Fields

address: SocketAddrAlreadyConnected
Fields

address: SocketAddrSelfConnect
Fields

address: SocketAddrBannedIp
IoError(Error)
ApplicationError(Box<dyn ApplicationError>)
Other(Box<dyn Error + Send + Sync>)
An unexpected error at the application layer and certain deserialization errors. TODO(kaimast): (some of) these should be treated with higher severity, as they indicate a bug or corrupted state, and deserialization errors should not be included in this “other” category.
Implementations
Sourceimpl ConnectError
impl ConnectError
Sourcepub fn application<E: ApplicationError>(err: E) -> Self
pub fn application<E: ApplicationError>(err: E) -> Self
Pass an application-level error to the Tcp stack.